[open-ils-commits] [GIT] Evergreen ILS branch master updated. f78a75121cd7f622ea63cd04fbd431ebd15d5fcf

Evergreen Git git at git.evergreen-ils.org
Fri Mar 3 22:01:09 EST 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, master has been updated
       via  f78a75121cd7f622ea63cd04fbd431ebd15d5fcf (commit)
      from  c2ff26aa8cb050c15b4124ec8d3402422fd3dcb1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit f78a75121cd7f622ea63cd04fbd431ebd15d5fcf
Author: Jason Stephenson <jason at sigio.com>
Date:   Fri Dec 9 21:21:35 2016 -0500

    LP 1648922: Hide orgs that can't have users in workstation registration.
    
    A user can register a workstation at an org unit that can't have users
    in the webstaff client.  The XUL staff client did not allow this.
    Such org units were grayed out in the selector.
    
    This commit hides org units that can't have users in the ou selector
    for workstation registration in the webstaff client.  This is in
    addition to hiding the existing hiding of org units where the user
    does not have the REGISTER_WORKSTATION permission.
    
    To reproduce this bug, see that org units that have false for
    can_have_users appear in the selection for workstation registration.
    Also see that you can register a workstation at one.
    
    After applying this patch, make sure you've logged out and then log in
    to the webstaff client.  You will now see that those org units no
    longer appear in the slection list.  You cannot register workstations
    at those org units any longer.
    
    Signed-off-by: Jason Stephenson <jason at sigio.com>
    Signed-off-by: Michele Morgan <mmorgan at noblenet.org>
    Signed-off-by: Kathy Lussier <klussier at masslnc.org>

diff --git a/Open-ILS/web/js/ui/default/staff/admin/workstation/app.js b/Open-ILS/web/js/ui/default/staff/admin/workstation/app.js
index a25d719..15c1fcb 100644
--- a/Open-ILS/web/js/ui/default/staff/admin/workstation/app.js
+++ b/Open-ILS/web/js/ui/default/staff/admin/workstation/app.js
@@ -729,9 +729,10 @@ function($scope , $q , $window , $location , egCore , egAlertDialog , workstatio
         reg_perm_orgs = orgList;
 
         // hide orgs in the context org selector where this login
         // does not have the reg_ws perm
         $scope.wsOrgHidden = function(id) {
-            return reg_perm_orgs.indexOf(id) == -1;
+            return reg_perm_orgs.indexOf(id) == -1
+                || $scope.cant_have_users(id);
         }
 
     // fetch the locally stored workstation data

-----------------------------------------------------------------------

Summary of changes:
 .../js/ui/default/staff/admin/workstation/app.js   |    5 +++--
@@ -729,9 +729,10 @@ function($scope , $q , $window , $location , egCore , egAlertDialog , workstatio
 
         // hide orgs in the context org selector where this login
-        // does not have the reg_ws perm
+        // does not have the reg_ws perm or the org can't have users
         $scope.wsOrgHidden = function(id) {
 1 files changed, 3 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
Evergreen ILS


More information about the open-ils-commits mailing list